@@ -1,5 +1,8 @@
 #ifndef __COLORS_H
 #define __COLORS_H
+
+/* numbers of color pairs in curses color definitions */
+
 #define NORMAL 1
 #define MENUSELECTED 2
 #define NOTESELECTED 3
@@ -12,6 +15,9 @@
 #define URL 10
 #define URLSELECTED 11
 #define INFOHIGHLIGHT 12
+#define SEARCHHIGHLIGHT 13
+
+/* those bellow hold color attributes for named screen widgets */
 
 extern int menu;
 extern int menuselected;
@@ -25,7 +31,11 @@ extern int manualitalic;
 extern int url;
 extern int urlselected;
 extern int infohighlight;
+extern int searchhighlight;
 
-void initcolors ();
+void initcolors ();		/* 
+				 * initialize color values/attributes/etc. 
+				 * Either for color and monochrome mode.
+				 */
 
 #endif
