@@ -15,6 +15,9 @@
 #include <signal.h>
 #include <unistd.h>
 #include <sys/types.h>
+#include <sys/stat.h>
+#include <pwd.h>
+#include <grp.h>
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -33,6 +36,7 @@
 #include "parse_config.h"
 #include "keyboard.h"
 #include "initializelinks.h"
+#include "printinfo.h"
 
 /*
  * Readline isn't safe for nonlinux terminals (i.e. vt100)
