@@ -24,10 +24,8 @@ work (char ***message, char **type, long *lines, FILE * id, int tag_table_pos)
   int indirectstart = -1;
   int cursorchanged = 0;
   int key = 0;
-  int highlight_searched = 0;
   int return_value;
   char *token, *tmp;
-  char searchword[256];
 
   if (rval.file)		/* if the static variable was allocated, free it */
     {
@@ -66,11 +64,7 @@ work (char ***message, char **type, long *lines, FILE * id, int tag_table_pos)
 				 * 's'earch function.
 				 */
     {
-      highlight_searched = 1;
-      copy_stripped_from_regexp (searchagain.lastsearch, searchword);
       pos = aftersearch;	/* set pos to the found position */
-      aftersearch = 0;
-
     }
 
   if (ncursor != -1)
@@ -93,20 +87,6 @@ work (char ***message, char **type, long *lines, FILE * id, int tag_table_pos)
       if (key == ERR)
 	{
 	  showscreen (Message, Type, Lines, pos, cursor);
-	  if (highlight_searched)
-	    {
-	      char *highlightstart = strstr ((*message)[pos], searchword);
-	      attrset (searchhighlight);
-	      if (highlightstart)
-		{
-		  mvaddstr (1,
-			    calculate_len ((*message)[pos], highlightstart),
-			    searchword);
-		}
-	      highlight_searched = 0;
-	      attrset (normal);
-	      move (0, 0);
-	    }
 	  nodelay (stdscr, FALSE);
 	  key = pinfo_getch ();
 	}
@@ -192,6 +172,8 @@ work (char ***message, char **type, long *lines, FILE * id, int tag_table_pos)
 	      curs_set (0);
 	      if (pipe == NULL)
 		mvaddstr (maxy - 1, 0, _ ("Operation failed..."));
+	      xfree (token);
+	      token = 0;
 	    }
 /*==========================================================================*/
 	  if ((key == keys.dirpage_1) ||
@@ -201,6 +183,7 @@ work (char ***message, char **type, long *lines, FILE * id, int tag_table_pos)
 	      strcpy (rval.file, "dir");
 	      rval.node = malloc (2);
 	      strcpy (rval.node, "");
+	      aftersearch = 0;
 	      return rval;
 	    }
 /*==========================================================================*/
@@ -425,7 +408,7 @@ work (char ***message, char **type, long *lines, FILE * id, int tag_table_pos)
 			for (i = TagTableEntries; i >= 1; i--)
 			  {
 			    if ((tag_table[i].offset > tag_table[tmpvar].offset) &&
-				((tag_table[i].offset + FirstNodeOffset) <= tokenpos))
+				(tag_table[i].offset <= tokenpos))
 			      {
 				return_value = i;
 				tmpvar = i;
@@ -558,8 +541,7 @@ work (char ***message, char **type, long *lines, FILE * id, int tag_table_pos)
 	      xfree (token);	/* free user's search token */
 	      token = 0;
 	      rescan_cursor ();	/* rescan cursor position in the new place */
-	      highlight_searched = 1;
-	      copy_stripped_from_regexp (searchagain.lastsearch, searchword);
+	      aftersearch = 1;
 	    }
 /*==========================================================================*/
 	  if ((key == keys.search_again_1) ||	/* search again */
@@ -607,6 +589,7 @@ work (char ***message, char **type, long *lines, FILE * id, int tag_table_pos)
 		  strcpy (rval.node, tag_table[return_value].nodename);
 		  rval.file = xmalloc (1);
 		  rval.file[0] = 0;
+		  aftersearch = 0;
 		  return rval;
 		}
 	      else
@@ -640,6 +623,7 @@ work (char ***message, char **type, long *lines, FILE * id, int tag_table_pos)
 			  strcpy (rval.node, gotoendptr);
 			  xfree (token);
 			  token = 0;
+			  aftersearch = 0;
 			  return rval;
 			}
 		    }
@@ -655,6 +639,7 @@ work (char ***message, char **type, long *lines, FILE * id, int tag_table_pos)
 		      token = 0;
 		      rval.node = xmalloc (5);
 		      strcpy (rval.node, "");
+		      aftersearch = 0;
 		      return rval;
 		    }
 		  else
@@ -689,6 +674,7 @@ work (char ***message, char **type, long *lines, FILE * id, int tag_table_pos)
 		  strcpy (rval.node, tag_table[return_value].nodename);
 		  rval.file = xmalloc (1);
 		  rval.file[0] = 0;
+		  aftersearch = 0;
 		  return rval;
 		}
 	    }
@@ -709,6 +695,7 @@ work (char ***message, char **type, long *lines, FILE * id, int tag_table_pos)
 		  strcpy (rval.node, tag_table[return_value].nodename);
 		  rval.file = xmalloc (1);
 		  rval.file[0] = 0;
+		  aftersearch = 0;
 		  return rval;
 		}
 	    }
@@ -729,6 +716,7 @@ work (char ***message, char **type, long *lines, FILE * id, int tag_table_pos)
 		  strcpy (rval.node, tag_table[return_value].nodename);
 		  rval.file = xmalloc (1);
 		  rval.file[0] = 0;
+		  aftersearch = 0;
 		  return rval;
 		}
 	    }
@@ -872,7 +860,7 @@ work (char ***message, char **type, long *lines, FILE * id, int tag_table_pos)
 		  }
 	      if (!cursorchanged)
 		{
-		  if (pos < Lines - (maxy - 1))
+		  if (pos <= Lines - (maxy - 1))
 		    pos++;
 		  for (i = cursor + 1; i < hyperobjectcount; i++)
 		    {
@@ -899,6 +887,7 @@ work (char ***message, char **type, long *lines, FILE * id, int tag_table_pos)
 	      strcpy (rval.node, FirstNodeName);
 	      rval.file = xmalloc (1);
 	      rval.file[0] = 0;
+	      aftersearch = 0;
 	      return rval;
 	    }
 /*==========================================================================*/
@@ -919,7 +908,7 @@ work (char ***message, char **type, long *lines, FILE * id, int tag_table_pos)
 		  npos = infohistory.pos[infohistory.length];
 		  ncursor = infohistory.cursor[infohistory.length];
 		  dellastinfohistory ();	/* remove history entry for previous node */
-
+		  aftersearch = 0;
 		  return rval;
 		}
 	    }
@@ -939,6 +928,7 @@ work (char ***message, char **type, long *lines, FILE * id, int tag_table_pos)
 			strcpy (rval.node, hyperobjects[cursor].node);
 			rval.file = xmalloc (strlen (hyperobjects[cursor].file) + 1);
 			strcpy (rval.file, hyperobjects[cursor].file);
+			aftersearch = 0;
 			return rval;
 		      }
 		    else if (hyperobjects[cursor].type < HIGHLIGHT)	/* we deal with an url */
@@ -1100,6 +1090,7 @@ work (char ***message, char **type, long *lines, FILE * id, int tag_table_pos)
 	    }
 	}
     }
+  aftersearch = 0;
   return rval;
 }
 void
