@@ -33,6 +33,9 @@ int selected = -1;		/* number of selected link (offset in 'manuallinks',
 int manualpos = 0;		/* number of the first line, which is painted on
 				   screen */
 
+int manual_aftersearch = 0;	/* this is set if man page is now after search 
+				   operation */
+
 typedef struct
   {
     char name[256];		/* name of a manual */
@@ -173,9 +176,9 @@ handlemanual (char *name)	/*
   getmaxyx (stdscr, maxy, maxx);	/* if ncurses, get maxx and maxy */
   myendwin ();
   {
-    char tmp[4];		/* set MANWIDTH environment variable */
-    snprintf (tmp, 4, "%d", maxx);
-    setenv ("MANWIDTH", tmp, 1);
+    char tmp[24];		/* set MANWIDTH environment variable */
+    snprintf (tmp, 24, "MANWIDTH=%d", maxx);
+    putenv (tmp);
   }
 #else
   maxx = 80;
@@ -666,14 +669,12 @@ manualwork ()			/* viewer function. Handles keyboard actions--main event loop */
   char *tmp;			/* again the same */
   int key = 0;			/* key, which contains the value entered by user */
   int i, selectedchanged;	/* tmp values */
-  int highlight_searched = 0;	/* is it time to highlight after search? */
-  char searchword[256];		/* buffer for searchword highlighter */
 #ifdef getmaxyx
   getmaxyx (stdscr, maxy, maxx);	/* if ncurses, get maxx and maxy */
   {
-    char tmp[4];		/* set MANWIDTH environment variable */
-    snprintf (tmp, 4, "%d", maxx);
-    setenv ("MANWIDTH", tmp, 1);
+    char tmp[24];		/* set MANWIDTH environment variable */
+    snprintf (tmp, 24, "MANWIDTH=%d", maxx);
+    putenv (tmp);
   }
 #else
   maxx = 80;
@@ -701,25 +702,6 @@ manualwork ()			/* viewer function. Handles keyboard actions--main event loop */
       if (key == ERR)		/* if there was nothing in buffer */
 	{
 	  showmanualscreen ();	/* then show screen */
-	  if (highlight_searched)
-	    {
-	      char *tmp = xmalloc (strlen (manual[manualpos]) + 10);
-	      char *highlightstart = 0;
-	      strcpy (tmp, manual[manualpos]);
-	      strip_manual (tmp);	/* we must do it without counting nonprintable chars */
-	      highlightstart = strstr (tmp, searchword);
-	      attrset (searchhighlight);
-	      if (highlightstart)
-		{
-		  mvaddstr (1,
-			    calculate_len (tmp, highlightstart),
-			    searchword);
-		}
-	      highlight_searched = 0;
-	      attrset (normal);
-	      move (0, 0);
-	      xfree (tmp);
-	    }
 	  nodelay (stdscr, FALSE);
 	  key = pinfo_getch ();
 	}
@@ -904,8 +886,7 @@ manualwork ()			/* viewer function. Handles keyboard actions--main event loop */
 		}
 	      xfree (token);
 	      rescan_selected ();
-	      highlight_searched = 1;
-	      copy_stripped_from_regexp (searchagain.lastsearch, searchword);
+	      manual_aftersearch = 1;
 	    }
 /*===========================================================================*/
 	  if ((key == keys.search_again_1) ||	/* search again */
@@ -1248,7 +1229,6 @@ showmanualscreen ()		/* show the currently visible part of manpage */
       mvaddstr_manual ((i - manualpos) + 1, 0, manual[i]);
       if (len)
 	manual[i][len - 1] = '\n';
-      myclrtoeol ();
     }
   clrtobot ();			/* and clear to bottom */
   add_highlights ();		/* add highlights */
@@ -1266,7 +1246,13 @@ showmanualscreen ()		/* show the currently visible part of manpage */
 void
 mvaddstr_manual (int y, int x, char *str)	/* print a manual line */
 {
-  int i, len = strlen (str);
+  int i, j, len = strlen (str);
+  static char strippedline[1024];
+  if ((h_regexp_num) || (manual_aftersearch))
+    {
+      memcpy (strippedline, str, len + 1);
+      strip_manual (strippedline);
+    }
   move (y, x);
   for (i = 0; i < len; i++)
     {
@@ -1311,6 +1297,33 @@ mvaddstr_manual (int y, int x, char *str)	/* print a manual line */
 	}
     label_skip_other:;
     }
+  myclrtoeol ();
+#ifndef ___DONT_USE_REGEXP_SEARCH___
+  if ((h_regexp_num) || (manual_aftersearch))
+    {
+      regmatch_t pmatch[1];
+      int maxregexp = manual_aftersearch ? h_regexp_num + 1 : h_regexp_num;
+      /* if it is after search, then we have user defined regexps+
+         a searched regexp to highlight */
+      for (j = 0; j < maxregexp; j++)
+	{
+	  char *tmpstr = strippedline;
+	  while (!regexec (&h_regexp[j], tmpstr, 1, pmatch, 0))
+	    {
+	      int n = pmatch[0].rm_eo - pmatch[0].rm_so, k;
+	      int rx = pmatch[0].rm_so + tmpstr - strippedline;
+	      char tmpchr;
+	      tmpchr = strippedline[rx + n];
+	      strippedline[rx + n] = 0;
+	      attrset (searchhighlight);
+	      mvaddstr (y, rx, strippedline + rx);
+	      attrset (normal);
+	      strippedline[rx + n] = tmpchr;
+	      tmpstr = tmpstr + pmatch[0].rm_eo;
+	    }
+	}
+    }
+#endif
 }
 void
 add_highlights ()		/* add hyperobject highlights */
