@@ -3,6 +3,9 @@
 
 #define COLOR_DEFAULT -1	/* mutt uses this was for transparency */
 
+regex_t *h_regexp = 0;		/* regexps to highlight */
+int h_regexp_num = 0;		/* number of those regexps */
+
 extern int use_apropos;
 extern int CutManHeaders;
 extern int DontHandleWithoutTagTable;
@@ -73,8 +76,10 @@ parse_config (void)
   char line[256];
   FILE *f;
   int line_number = 0;
-
-  home = strdup (getenv ("HOME"));
+  if (getenv ("HOME"))
+    home = strdup (getenv ("HOME"));
+  else
+    home = 0;
   if (home)
     {
       strcpy (config_file_name, home);
@@ -84,8 +89,7 @@ parse_config (void)
 	  strcpy (config_file_name, CONFIGDIR);
 	  if (!(f = fopen (config_file_name, "r")))
 	    {
-	      if (home)
-		free (home);
+	      free (home);	/* home is nonzero; see if(home) above */
 	      return 0;		/* no config file available */
 	    }
 	}
@@ -95,8 +99,7 @@ parse_config (void)
       strcpy (config_file_name, CONFIGDIR);
       if (!(f = fopen (config_file_name, "r")))
 	{
-	  if (home)
-	    free (home);
+/*        free (home);             home is unallocated; see if(home) above */
 	  return 0;
 	}
     }
@@ -600,6 +603,50 @@ parse_line (char *line)
       else
 	return 1;
     }
+#ifndef ___DONT_USE_REGEXP_SEARCH___
+  else if (!strncmp (temp, "HIGHLIGHTREGEXP", 15))
+    {
+      temp = strtok (NULL, "\n");
+      if (temp)
+	{
+	  char *tmp = strdup (temp);
+	  remove_quotes (tmp);
+	  if (!h_regexp_num)
+	    h_regexp = malloc (sizeof (regex_t));
+	  else
+	    h_regexp = realloc (h_regexp, sizeof (regex_t) * (h_regexp_num + 1));
+	  regcomp (&h_regexp[h_regexp_num], tmp, 0);
+	  free (tmp);
+	  h_regexp_num++;
+	}
+      else
+	return 1;
+    }
+#endif
+  else if (!strncmp (temp, "SAFE-USER", 9))
+    {
+      temp = strtok (NULL, "\n");
+      if (temp)
+	{
+	  char *tmp = strdup (temp);
+	  remove_quotes (tmp);
+	  safe_user = tmp;
+	}
+      else
+	return 1;
+    }
+  else if (!strncmp (temp, "SAFE-GROUP", 10))
+    {
+      temp = strtok (NULL, "\n");
+      if (temp)
+	{
+	  char *tmp = strdup (temp);
+	  remove_quotes (tmp);
+	  safe_group = tmp;
+	}
+      else
+	return 1;
+    }
   else if (!strncmp (temp, "QUOTE-IGNORED-MACROS", 20))
     {
       temp = strtok (NULL, "=");
