@@ -9,9 +9,6 @@
 #include <getopt.h>
 #endif
 
-#define	SAFE_USER	"nobody"
-#define	SAFE_GROUP	SAFE_USER
-
 char *version = VERSION;
 int DontHandleWithoutTagTable = 0;
 
@@ -61,12 +58,12 @@ main (int argc, char *argv[])
   signal_handler ();		/* take care of SIGSEGV, SIGTERM, SIGINT */
   searchagain.type = 0;
   searchagain.search = 0;
-  checksu ();
   initlocale ();
   inithistory ();
   printf ("Przemek's Info Viewer v%s\n", version);
   initpaths ();
   parse_config ();		/* read config information */
+  checksu ();
   if (argc == 1)		/* if no arguments were given */
     {
       id = openinfo ("dir", 0);
@@ -462,10 +459,10 @@ checksu ()
 
   if (!getegid () || !getgid ())
     {
-      grwd = getgrnam (SAFE_GROUP);
+      grwd = getgrnam (safe_group);
       if (!grwd)
 	{
-	  printf (_ ("Security warning: Unable to get GID of group called: %s\n"), SAFE_GROUP);
+	  printf (_ ("Security warning: Unable to get GID of group called: %s\n"), safe_group);
 	  sleep (1);
 	}
       else
@@ -479,10 +476,10 @@ checksu ()
 
   if (!geteuid () || !getuid ())
     {
-      pswd = getpwnam (SAFE_USER);
+      pswd = getpwnam (safe_user);
       if (!pswd)
 	{
-	  printf (_ ("Security warning: Unable to get UID of user called: %s\n"), SAFE_USER);
+	  printf (_ ("Security warning: Unable to get UID of user called: %s\n"), safe_user);
 	  sleep (1);
 	}
       else
