@@ -2,8 +2,11 @@
 #include <regex.h>
 #include <ctype.h>
 
+char *safe_user = "nobody";
+char *safe_group = "nobody";
+
 #ifndef HAVE_CURS_SET
-void 
+void
 curs_set (int a)
 {
 }
@@ -11,6 +14,8 @@ curs_set (int a)
 
 #ifdef ___DONT_USE_REGEXP_SEARCH___
 char *pinfo_re_pattern = 0;
+#else
+int pinfo_re_offset = -1;
 #endif
 
 /*
@@ -81,7 +86,6 @@ void *
 xmalloc (size_t size)
 {
   register void *value = malloc (size);
-  memset (value, 0, size);
 #ifdef ___DEBUG___
   unsigned long msize = 0;
   int i;
@@ -105,6 +109,7 @@ xmalloc (size_t size)
       fprintf (stderr, "trace buffer exhausted\n");
     }
 #endif /* ___DEBUG___ */
+  memset (value, 0, size);
   return value;
 }
 
@@ -332,7 +337,19 @@ pinfo_re_comp (char *name)
     }
   pinfo_re_pattern = strdup (name);
 #else
-  re_comp (name);
+  if (pinfo_re_offset == -1)
+    {
+      pinfo_re_offset = h_regexp_num;
+      if (!h_regexp_num)
+	h_regexp = malloc (sizeof (regex_t));
+      else
+	h_regexp = realloc (h_regexp, sizeof (regex_t) * (h_regexp_num + 1));
+    }
+  else
+    {
+      regfree (&h_regexp[pinfo_re_offset]);
+    }
+  regcomp (&h_regexp[pinfo_re_offset], name, REG_ICASE);
 #endif
 }
 int
@@ -349,7 +366,8 @@ pinfo_re_exec (char *name)
 	return 0;
     }
 #else
-  return re_exec (name);
+  regmatch_t pmatch[1];
+  return !regexec (&h_regexp[pinfo_re_offset], name, 1, pmatch, 0);
 #endif
 }
 
